summaryrefslogtreecommitdiff
path: root/vcl/aqua/inc/saldata.hxx
diff options
context:
space:
mode:
authorVladimir Glazounov <vg@openoffice.org>2008-07-01 22:02:57 +0000
committerVladimir Glazounov <vg@openoffice.org>2008-07-01 22:02:57 +0000
commit8264e00aee8c395051a01e3d89dfb6c8c559d98e (patch)
treee3745cbc46f2e3fa7542ce52067e199611a34b2e /vcl/aqua/inc/saldata.hxx
parent2217e2a2376ef45edec58b7a619a25f5fd9337c5 (diff)
INTEGRATION: CWS aquavcl08 (1.20.40); FILE MERGED
2008/06/02 09:04:50 pl 1.20.40.4: RESYNC: (1.20-1.21); FILE MERGED 2008/05/20 08:30:51 pl 1.20.40.3: system version is not a pointer 2008/05/20 08:06:40 ericb 1.20.40.2: #i89655# add constants for Mac OS X version detection 2008/05/19 18:48:44 ericb 1.20.40.1: #i89655# implement SystemVersion for aqua
Diffstat (limited to 'vcl/aqua/inc/saldata.hxx')
-rw-r--r--vcl/aqua/inc/saldata.hxx10
1 files changed, 7 insertions, 3 deletions
diff --git a/vcl/aqua/inc/saldata.hxx b/vcl/aqua/inc/saldata.hxx
index 8200592d5e31..8b1d677c4465 100644
--- a/vcl/aqua/inc/saldata.hxx
+++ b/vcl/aqua/inc/saldata.hxx
@@ -7,7 +7,7 @@
* OpenOffice.org - a multi-platform office productivity suite
*
* $RCSfile: saldata.hxx,v $
- * $Revision: 1.21 $
+ * $Revision: 1.22 $
*
* This file is part of OpenOffice.org.
*
@@ -61,6 +61,9 @@ class SystemFontList;
#define SAL_CLIPRECT_COUNT 16
+#define VER_TIGER 0x1040
+#define VER_LEOPARD 0x1050
+
// -----------
// - SalData -
// -----------
@@ -94,8 +97,9 @@ struct SalData
static oslThreadKey s_aAutoReleaseKey;
- bool mbIsScrollbarDoubleMax; // TODO: support DoubleMin and DoubleBoth too
- bool mbIsTestTool;
+ bool mbIsScrollbarDoubleMax; // TODO: support DoubleMin and DoubleBoth too
+ SInt32 mnSystemVersion; // Store System Version
+ bool mbIsTestTool;
SalData();
~SalData();